<?php

/**
 * Mails CPT Metaboxes
 *
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Mail_Builder
 * @subpackage Alexandria_Mail_Builder/admin/models
 */

/*
* Creating a function to create our CPT
*/

class Alexandria_Mail_Mails_Metaboxes {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


	function interlocutor_fields() {

		global $post;

		$selected_interlocutor = get_post_meta( $post->ID, '_interlocutor_email', true );

		$all_interlocutors = get_posts( array(
			'post_type' => 'interlocutors_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));

		?>

		<input type="hidden" name="interlocutor_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<div class="custom-metabox">

			<div class="metabox-right">

				<table class="form-table">

					<tr valign="top">

						<th scope="row">
							<label for="interlocutor_email">
								<?php _e('Interlocutor', 'alexandria-mail-builder'); ?>
							</label>
						</th>

						<td>

							<select id="select_interlocutor_email" name="interlocutor_email">

								<option value="0">
									<?php _e('Seleccionar', '').' '._e(' Interlocutor', ''); ?>
								</option>

								<?php foreach ( $all_interlocutors as $interlocutor ) : ?>
									<option value="<?php echo $interlocutor->ID; ?>" <?php echo $interlocutor->ID == $selected_interlocutor ? 'selected' : ''; ?>>
										<?php echo $interlocutor->post_title; ?>		
									</option>
								<?php endforeach; ?>

							</select>

						</td>

					</tr>

				</table>
				
			</div>

		</div>

		<?php 
	}

	function situation_fields() {

		global $post;

		$selected_situation = get_post_meta( $post->ID, '_situation_email', true );

		$all_situations = get_posts( array(
			'post_type' => 'situations_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="situation_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<th scope="row">
					<label for="situation_email"><?php _e('Situación', ''); ?></label>
				</th>

				<td>
					<select id="select_situation_email" name="situation_email">

						<option value="0"><?php _e('Seleccionar Situación', 'alexandria-mail-builder'); ?></option>

						<?php foreach ( $all_situations as $situation ) : ?>
							<option value="<?php echo $situation->ID; ?>" <?php echo $situation->ID == $selected_situation ? 'selected' : ''; ?>>
								<?php echo $situation->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

		function tono_fields() {

		global $post;

		$selected_tono = get_post_meta( $post->ID, '_tono_email', true );

		$all_tonos = get_posts( array(
			'post_type' => 'tonos_email',
			'numberposts' => -1,
			'orderby' => 'title',
			'order' => 'ASC'
		));

		?>

		<input type="hidden" name="tono_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">
				<th scope="row">
					<label for="tono_email"><?php _e('Tono', ''); ?></label>
				</th>
				<td>
					<select id="select_tono_email" name="tono_email">

						<option value="0"><?php _e('Seleccionar Tono', 'alexandria-mail-builder') ?></option>

						<?php foreach ( $all_tonos as $tono ) : ?>
							<option value="<?php echo $tono->ID; ?>" <?php echo $tono->ID == $selected_tono ? 'selected' : ''; ?>>
								<?php echo $tono->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>
				</td>
			</tr>

		</table>

		<?php 
	}

	function gran_idea_email_fields() {

		global $post;

		$selected_gran_idea_email = get_post_meta( $post->ID, '_gran_idea_email', true );

		$all_gran_ideas_email = get_posts( array(
			'post_type' => 'gran_ideas_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); 

		?>

		<input type="hidden" name="gran_idea_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_gran_idea_email" name="gran_idea_email[]">

						<?php foreach ( $all_gran_ideas_email as $gran_ideas_email ) : ?>
							<option value="<?php echo $gran_ideas_email->ID; ?>"	
								<?php 

								if(is_array($selected_gran_idea_email)) {
									echo (in_array($gran_ideas_email->ID, $selected_gran_idea_email) ? 'selected' : '');
								} else {
									echo $gran_ideas_email->ID == $selected_gran_idea_email ? 'selected' : '';
								}

								?>

								>

								<?php echo $gran_ideas_email->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function arguments_email_fields() {

		global $post;

		$selected_arguments_email = get_post_meta( $post->ID, '_arguments_email', true );

		$all_arguments_email = get_posts( array(
			'post_type' => 'arguments_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="arguments_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_arguments_email" name="arguments_email[]">

						<?php foreach ( $all_arguments_email as $arguments_email ) : ?>
							<option value="<?php echo $arguments_email->ID; ?>"	
								<?php 

								if(is_array($selected_arguments_email)) {
									echo (in_array($arguments_email->ID, $selected_arguments_email) ? 'selected' : '');
								} else {
									echo $arguments_email->ID == $selected_arguments_email ? 'selected' : '';
								}

								?>

								>

								<?php echo $arguments_email->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function content_boxes_fields() {

		global $post;

		$selected_content_boxes = get_post_meta( $post->ID, '_content_boxes', true );

		$all_content_boxes = get_posts( array(
			'post_type' => 'content_boxes',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="content_boxes_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_content_boxes" name="content_boxes[]">

						<?php foreach ( $all_content_boxes as $content_boxes ) : ?>
							<option value="<?php echo $content_boxes->ID; ?>" 

								<?php 

								if(is_array($selected_content_boxes)) {
									echo (in_array($content_boxes->ID, $selected_content_boxes) ? 'selected' : '');
								} else {
									echo $content_boxes->ID == $selected_content_boxes ? 'selected' : '';
								}

								?>

								>

								<?php echo $content_boxes->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function engagement_boxes_fields() {

		global $post;

		$selected_engagement_boxes = get_post_meta( $post->ID, '_engagement_boxes', true );	

		$all_engagement_boxes = get_posts( array(
			'post_type' => 'engagement_boxes',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));


		?>
		
		<input type="hidden" name="engagement_boxes_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />
		
		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					
					<select multiple id="select_engagement_boxes" name="engagement_boxes[]">

						<?php foreach ( $all_engagement_boxes as $engagement_box ) : ?>

							<option title="<?php echo $engagement_box->post_title; ?>" value="<?php echo $engagement_box->ID; ?>"
								<?php 

								if(is_array($selected_engagement_boxes)) {
									echo (in_array($engagement_box->ID, $selected_engagement_boxes) ? 'selected' : '');
								} else {
									echo $engagement_box->ID == $selected_engagement_boxes ? 'selected' : '';
								}

								?>

								>
								<?php echo substr($engagement_box->post_title, 0, 100); ?>		
							</option>

						<?php endforeach; ?>

					</select>

				</td>

			</tr> 

		</table>

		<?php
	}

	function ingredients_fields() {

		global $post;

		$selected_ingredients = get_post_meta( $post->ID, '_ingredients', true );

		$all_ingredients = get_posts( array(
			'post_type' => 'ingredients',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="ingredients_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_ingredients" name="ingredients[]">

						<?php foreach ( $all_ingredients as $expect_result ) : ?>
							<option value="<?php echo $expect_result->ID; ?>" 
								<?php 

								if(is_array($selected_ingredients)) {
									echo (in_array($expect_result->ID, $selected_ingredients) ? 'selected' : '');
								} else {
									echo $expect_result->ID == $selected_ingredients ? 'selected' : '';
								}

								?>

								>
								<?php echo $expect_result->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}


	function soliloquios_fields() {

		global $post;

		$selected_soliloquios = get_post_meta( $post->ID, '_soliloquios_email', true );

		$all_soliloquios = get_posts( array(
			'post_type' => 'soliloquios_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="soliloquios_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_soliloquios_emails" name="soliloquios_email[]">

						<?php foreach ( $all_soliloquios as $soliloquio ) : ?>

							<option value="<?php echo $soliloquio->ID; ?>"

								<?php 

								if(is_array($selected_soliloquios)) {
									echo (in_array($soliloquio->ID, $selected_soliloquios) ? 'selected' : '');
								} else {
									echo $soliloquio->ID == $selected_soliloquios ? 'selected' : '';
								}

								?>

								>

								<?php echo $soliloquio->post_title; ?>	
							</option>

						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function gran_idea_pitch_fields() {

		global $post;

		$selected_gran_idea_pitch = get_post_meta( $post->ID, '_gran_idea_pitch', true );

		$all_gran_idea_pitch = get_posts( array(
			'post_type' => 'gran_ideas_pitch',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="gran_idea_pitch_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="gran_idea_pitch" name="gran_idea_pitch[]">

						<?php foreach ( $all_gran_idea_pitch as $gran_idea_pitch ) : ?>
							<option value="<?php echo $gran_idea_pitch->ID; ?>" 
								<?php 

								if(is_array($selected_gran_idea_pitch)) {
									echo (in_array($gran_idea_pitch->ID, $selected_gran_idea_pitch) ? 'selected' : '');
								} else {
									echo $gran_idea_pitch->ID == $selected_gran_idea_pitch ? 'selected' : '';
								}

								?>

								>
								<?php echo $gran_idea_pitch->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function arguments_pitch_fields() {

		global $post;

		$selected_arguments = get_post_meta( $post->ID, '_arguments_pitch', true );

		$all_arguments_pitch = get_posts( array(
			'post_type' => 'arguments_pitch',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); 

		?>

		<input type="hidden" name="arguments_pitch_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_arguments_pitch" name="arguments_pitch[]">

						<?php foreach ( $all_arguments_pitch as $argument_pitch ) : ?>
							<option value="<?php echo $argument_pitch->ID; ?>"
								<?php 

								if(is_array($selected_arguments)) {
									echo (in_array($argument_pitch->ID, $selected_arguments) ? 'selected' : '');
								} else {
									echo $argument_pitch->ID == $selected_arguments ? 'selected' : '';
								}

								?>

								>
								<?php echo $argument_pitch->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function call_to_action_fields() {

		global $post;

		$selected_call_to_action = get_post_meta( $post->ID, '_call_to_action', true );

		$all_call_to_action = get_posts( array(
			'post_type' => 'call_to_action_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); 

		?>

		<input type="hidden" name="call_to_action_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_call_to_action" name="call_to_action[]">

						<?php foreach ( $all_call_to_action as $call_to_action ) : ?>
							<option value="<?php echo $call_to_action->ID; ?>"
								<?php 

								if(is_array($selected_call_to_action)) {
									echo (in_array($call_to_action->ID, $selected_call_to_action) ? 'selected' : '');
								} else {
									echo $call_to_action->ID == $selected_call_to_action ? 'selected' : '';
								}

								?>

								>
								<?php echo $call_to_action->post_title; ?>		
							</option>
						<?php endforeach; ?>

					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function email_builder_examples_fields() {

		global $post;

		$selected_examples = get_post_meta( $post->ID, '_examples_email', true );

		$all_examples = get_posts( array(
			'post_type' => 'examples_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		)); ?>

		<input type="hidden" name="examples_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ )); ?>" />

		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					<select multiple id="select_examples_email" name="examples_email[]">
						<?php foreach ( $all_examples as $example ) : ?>
							<option value="<?php echo $example->ID; ?>" 

								<?php 

								if(is_array($selected_examples)) {
									echo (in_array($example->ID, $selected_examples) ? 'selected' : '');
								} else {
									echo $example->ID == $selected_examples ? 'selected' : '';
								}

								?>

								>
								<?php echo $example->post_title; ?>		
							</option>
						<?php endforeach; ?>
					</select>

				</td>

			</tr>

		</table>

		<?php 
	}

	function alexandria_email_comments_fields() {

		global $post;

		$selected_comments_email = get_post_meta( $post->ID, '_comments_email', true );	

		$all_comments_email = get_posts( array(
			'post_type' => 'comments_email',
			'numberposts' => -1,
			'orderby' => 'post_title',
			'order' => 'ASC'
		));


		?>
		
		<input type="hidden" name="comments_email_nonce" value="<?php echo wp_create_nonce( basename( __FILE__ ) ); ?>" />
		
		<table class="form-table">

			<tr valign="top">

				<td style="margin-left: 15px;">
					
					<select multiple id="select_comments_email" name="comments_email[]">

						<?php foreach ( $all_comments_email as $comment ) : ?>

							<option title="<?php echo $comment->post_title; ?>" value="<?php echo $comment->ID; ?>"
								<?php 

								if(is_array($selected_comments_email)) {
									echo (in_array($comment->ID, $selected_comments_email) ? 'selected' : '');
								} else {
									echo $comment->ID == $selected_comments_email ? 'selected' : '';
								}

								?>

								>
								<?php echo substr($comment->post_title, 0, 100); ?>...		
							</option>

						<?php endforeach; ?>

					</select>

				</td>

			</tr> 

		</table>

		<?php
	}


	function alexandria_emails_save_custom_fields( $post_id ) {

    	// only run this for emails
		if ( 'emails' != get_post_type( $post_id ) )
			return $post_id;        

    	// verify nonces
		if ( empty( $_POST['interlocutor_email_nonce'] ) || !wp_verify_nonce( $_POST['interlocutor_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['situation_email_nonce'] ) || !wp_verify_nonce( $_POST['situation_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['tono_email_nonce'] ) || !wp_verify_nonce( $_POST['tono_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;


		if ( empty( $_POST['gran_idea_email_nonce'] ) || !wp_verify_nonce( $_POST['gran_idea_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['arguments_email_nonce'] ) || !wp_verify_nonce( $_POST['arguments_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['content_boxes_nonce'] ) || !wp_verify_nonce( $_POST['content_boxes_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['engagement_boxes_nonce'] ) || !wp_verify_nonce( $_POST['engagement_boxes_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['ingredients_nonce'] ) || !wp_verify_nonce( $_POST['ingredients_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['soliloquios_email_nonce'] ) || !wp_verify_nonce( $_POST['soliloquios_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['gran_idea_pitch_nonce'] ) || !wp_verify_nonce( $_POST['gran_idea_pitch_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['arguments_pitch_nonce'] ) || !wp_verify_nonce( $_POST['arguments_pitch_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['call_to_action_nonce'] ) || !wp_verify_nonce( $_POST['call_to_action_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['examples_email_nonce'] ) || !wp_verify_nonce( $_POST['examples_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

		if ( empty( $_POST['comments_email_nonce'] ) || !wp_verify_nonce( $_POST['comments_email_nonce'], basename( __FILE__ ) ) )
			return $post_id;

    	// check autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;

    	// check permissions
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;


    	// Save single values
		update_post_meta($post_id, '_interlocutor_email', intval($_POST['interlocutor_email']));
		update_post_meta($post_id, '_situation_email', intval($_POST['situation_email']));
		update_post_meta($post_id, '_tono_email', intval($_POST['tono_email']));


		// Save Multiples values
		if(isset($_POST['gran_idea_email'])) {
			update_post_meta($post_id, '_gran_idea_email', array_map('intval', $_POST['gran_idea_email']));
		} else {
			update_post_meta($post_id, '_gran_idea_email', array());
		}

		if(isset($_POST['arguments_email'])) {
			update_post_meta($post_id, '_arguments_email', array_map('intval', $_POST['arguments_email']));
		} else {
			update_post_meta($post_id, '_arguments_email', array());
		}

		if(isset($_POST['content_boxes'])) {
			update_post_meta($post_id, '_content_boxes', array_map('intval', $_POST['content_boxes']));
		} else {
			update_post_meta($post_id, '_content_boxes', array());
		}

		if(isset($_POST['engagement_boxes'])) {
			update_post_meta($post_id, '_engagement_boxes', array_map('intval', $_POST['engagement_boxes']));
		} else {
			update_post_meta($post_id, '_engagement_boxes', array());
		}

		if(isset($_POST['ingredients'])) {
			update_post_meta($post_id, '_ingredients', array_map('intval', $_POST['ingredients']));
		} else {
			update_post_meta($post_id, '_ingredients', array());
		}

		if(isset($_POST['soliloquios_email'])) {
			update_post_meta($post_id, '_soliloquios_email', array_map('intval', $_POST['soliloquios_email']));
		} else {
			update_post_meta($post_id, '_soliloquios_email', array());
		}

		if(isset($_POST['gran_idea_pitch'])) {
			update_post_meta($post_id, '_gran_idea_pitch', array_map('intval', $_POST['gran_idea_pitch']));
		} else {
			update_post_meta($post_id, '_gran_idea_pitch', array());
		}

		if(isset($_POST['arguments_pitch'])) {
			update_post_meta($post_id, '_arguments_pitch', array_map('intval', $_POST['arguments_pitch']));
		} else {
			update_post_meta($post_id, '_arguments_pitch', array());
		}

		if(isset($_POST['call_to_action'])) {
			update_post_meta($post_id, '_call_to_action', array_map('intval', $_POST['call_to_action']));
		} else {
			update_post_meta($post_id, '_call_to_action', array());
		}

		if(isset($_POST['examples_email'])) {
			update_post_meta($post_id, '_examples_email', array_map('intval', $_POST['examples_email']));
		} else {
			update_post_meta($post_id, '_examples_email', array());
		}

		if(isset($_POST['comments_email'])) {
			update_post_meta($post_id, '_comments_email', array_map('intval', $_POST['comments_email']));
		} else {
			update_post_meta($post_id, '_comments_email', array());
		}

	}

	function emails_column_register_sortable($columns){
		$columns['interlocutor_email'] = 'interlocutor_email';
		$columns['situation_email'] = 'situation_email';
		$columns['tono_email'] = 'tono_email';

		$columns['gran_idea_email'] = 'gran_idea_email';
		$columns['arguments_email'] = 'arguments_email';
		$columns['content_boxes'] = 'content_boxes';
		$columns['engagement_boxes'] = 'engagement_boxes';
		$columns['ingredients'] = 'ingredients';

		$columns['soliloquios_email'] = 'soliloquios_email';
		$columns['arguments_pitch'] = 'arguments_pitch';
		$columns['gran_idea_pitch'] = 'gran_idea_pitch';
		$columns['call_to_action'] = 'call_to_action';
		$columns['comments_email'] = 'comments_email';
		$columns['examples_email'] = 'examples_email';
		
		return $columns;
	}

	// Add the custom columns to the book post type:
	function set_custom_edit_emails_columns($columns) {
		unset( $columns['title'] );
		unset( $columns['date'] );
		$columns['interlocutor_email'] = __( 'Interlocutor', 'alexandria-mail-builder' );
		$columns['situation_email'] = __( 'Situación', 'alexandria-mail-builder' );
		$columns['tono_email'] = __( 'Tono', 'alexandria-mail-builder' );

		$columns['gran_idea_email'] = __( 'Gran Ideas - Email', 'alexandria-mail-builder' );
		$columns['arguments_email'] = __( 'Argumentos - E-mail', 'alexandria-mail-builder' );
		$columns['content_boxes'] = __( 'Cajas de Contenido', 'alexandria-mail-builder' );
		$columns['engagement_boxes'] = __( 'Cajas de Engagement', 'alexandria-mail-builder' );
		$columns['ingredients'] = __( 'Ingredientes', 'alexandria-mail-builder' );

		$columns['soliloquios_email'] = __( 'Soliloquios', 'alexandria-mail-builder' );
		$columns['gran_idea_pitch'] = __( 'Gran Ideas - Pitch', 'alexandria-mail-builder' );
		$columns['arguments_pitch'] = __( 'Argumentos - Pitch', 'alexandria-mail-builder' );
		$columns['call_to_action'] = __( 'Llamadas a la acción', 'alexandria-mail-builder' );

		$columns['comments_email'] = __( 'Comentarios', 'alexandria-mail-builder' );
		$columns['examples_email'] = __( 'Ejemplos', 'alexandria-mail-builder' );

		return $columns;
	}

	// Add the data to the custom columns for the book post type:
	function custom_emails_column( $column, $post_id ) {

		switch ( $column ) {

			case 'interlocutor_email' :
			$interlocutor = get_post_meta( $post_id, '_interlocutor_email', true );
			if($interlocutor != null){
				echo get_the_title($interlocutor);
			} else {
				_e('Sin Interlocutor', 'alexandria-mail-builder');
			}
			break;
			case 'situation_email' :
			$situation = get_post_meta( $post_id, '_situation_email', true );
			if($situation != null){
				echo get_the_title($situation );
			} else {
				_e('Sin Situación', 'alexandria-mail-builder');
			}
			break;
			case 'tono_email' :
			$tono = get_post_meta( $post_id, '_tono_email', true );
			if($tono != null){
				echo get_the_title($tono);
			} else {
				_e('Sin Tono', 'alexandria-mail-builder');
			}
			break;
			case 'gran_idea_email' :
			$gran_idea_email = get_post_meta( $post_id, '_gran_ideas_email', true );
			if($gran_idea_email != null){
				echo get_the_title($gran_idea_email);
			} else {
				_e('Sin Grandes Ideas', 'alexandria-mail-builder');
			}
			break;
			case 'arguments_email' :
			$arguments_email = get_post_meta( $post_id, '_arguments_email', true );
			if($arguments_email != null){
				foreach ($arguments_email as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Argumentos - E-mail', 'alexandria-mail-builder');
			}
			break;
			case 'content_boxes' :
			$content_boxes = get_post_meta( $post_id, '_content_boxes', true );
			if($content_boxes != null){
				foreach ($content_boxes as $value ) {
					echo get_the_title($value).',';
				}
			} else {
				_e('Sin Cajas de Contenido', 'alexandria-mail-builder');
			}
			break;
			case 'engagement_boxes' :
			$engagement_boxes = get_post_meta( $post_id, '_engagement_boxes', true );
			if($engagement_boxes != null){
				foreach ($engagement_boxes as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Cajas de Engagement', 'alexandria-mail-builder');
			}
			break;
			case 'ingredients' :
			$ingredients = get_post_meta( $post_id, '_ingredients', true );
			if($ingredients != null){
				foreach ($ingredients as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Ingredientes', 'alexandria-mail-builder');
			}
			break;
			case 'soliloquios_email' :
			$soliloquios = get_post_meta( $post_id, '_soliloquios_email', true );
			if($soliloquios != null){
				foreach ($soliloquios as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Soliloquios', 'alexandria-mail-builder');
			}
			break;
			case 'gran_idea_pitch' :
			$gran_idea_pitch = get_post_meta( $post_id, '_gran_idea_pitch', true );
			if($gran_idea_pitch != null){
				foreach ($gran_idea_pitch as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Gran Ideas - Pitch', 'alexandria-mail-builder');
			}
			break;
			case 'arguments_pitch' :
			$arguments_pitch = get_post_meta( $post_id, '_arguments_pitch', true );
			if($arguments_pitch != null){
				foreach ($arguments_pitch as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Argumentos - Pitch', 'alexandria-mail-builder');
			}
			break;
			case 'call_to_action' :
			$call_to_action = get_post_meta( $post_id, '_call_to_action', true );
			if($call_to_action != null){
				foreach ($call_to_action as $value ) {
					echo get_the_title($value).',';
				}	
			} else {
				_e('Sin Llamadas a la acción', 'alexandria-mail-builder');
			}
			break;
			case 'examples_email' :
			$examples = get_post_meta( $post_id, '_examples_email', true );
			if($examples != null){
				foreach ($examples as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Ejemplos', 'alexandria-mail-builder');
			}
			break;
			case 'comments_email' :
			$comments_email = get_post_meta( $post_id, '_comments_email', true );
			if($comments_email != null){
				foreach ($comments_email as $value ) {
					echo get_the_title($value). ',';
				}	
			} else {
				_e('Sin Comentarios', 'alexandria-mail-builder');
			}
			break;
		}
	}

	/**
	 * Display a custom taxonomy dropdown in admin
	 * @author Mike Hemberger
	 * @link http://thestizmedia.com/custom-post-type-filter-admin-custom-taxonomy/
	 */
	

	function tsm_filter_post_type_by_taxonomy() {
		$type = 'post';
		if (isset($_GET['post_type'])) {
			$type = $_GET['post_type'];
		}

		if ('mails' == $type){

			$all_interlocutors = get_posts( array(
				'post_type' => 'interlocutors',
				'numberposts' => -1,
				'orderby' => 'post_title',
				'order' => 'ASC'
			));

			?>
			<select name="interlocutor_id">

				<option value=""><?php _e('Filtrar por ', 'alexandria-mail-builder'); ?></option>

				<?php

				$current_v = isset($_GET['interlocutor_id']) ? $_GET['interlocutor_id'] : '';

				foreach ($all_interlocutors as $value) {
					printf
					(
						'<option value="%s"%s>%s</option>',
						$value->ID,
						$value->ID == $current_v? ' selected="selected"':'',
						$value->post_title
					);
				}
				?>
			</select>
			<?php
		}
	}

	/**
	 * Filter posts by custom metabox field in admin
	 * @author  Mike Hemberger
	 * @link http://thestizmedia.com/custom-post-type-filter-admin-custom-taxonomy/
	 */
	function tsm_convert_id_to_term_in_query($query) {

		global $pagenow;

		$type = 'post';

		if (isset($_GET['post_type'])) {
			$type = $_GET['post_type'];
		}

		if ( 'POST_TYPE' == $type && is_admin() && $pagenow=='edit.php' && isset($_GET['interlocutor_id']) && $_GET['interlocutor_id'] != '') {
			$query->query_vars['meta_key'] = '_interlocutor';
			$query->query_vars['meta_value'] = $_GET['interlocutor_id'];
		}
	}

}